@@ -1,22 +1,26 @@
 """ Module that contains classes for setting up connections to QualysGuard API
 and requesting data from it.
 """
-import requests, urlparse
 import logging
-import lxml.etree
+# Setup module level logging.
+logger = logging.getLogger(__name__)
+
+import requests, urlparse
 import qualysapi.version
 import qualysapi.api_methods
 import subprocess
 import urllib
 
 from collections import defaultdict
+try:
+    from lxml import etree
+except ImportError, e:
+    logger.error('Cannot understand lxml.builder E objects.')
 
 __author__ = 'Parag Baxi <parag.baxi@gmail.com>'
 __copyright__ = 'Copyright 2013, Parag Baxi'
 __license__ = 'Apache License 2.0'
 
-# Setup module level logging.
-logger = logging.getLogger(__name__)
 
 class QGConnector:
     """ Qualys Connection class which allows requests to the QualysGuard API using HTTP-Basic Authentication (over SSL).
@@ -24,7 +28,7 @@ class QGConnector:
     """
 
 
-    def __init__(self, username, password, server='qualysapi.qualys.com', proxies=None, curl_path=None, curl_use_subprocess=False):
+    def __init__(self, username, password, server='qualysapi.qualys.com', proxies=None):
         # Read username & password from file, if possible.
         self.auth = (username, password,)
         # Remember QualysGuard API server.
@@ -39,16 +43,6 @@ class QGConnector:
         self.api_methods_with_trailing_slash = qualysapi.api_methods.api_methods_with_trailing_slash
         self.proxies = proxies
         logger.debug('proxies = \n%s' % proxies)
-        self.curl_path = curl_path
-        logger.debug('curl_path = \n%s' % curl_path)
-        # Library human_curl may have issues, see if subprocess will be used.
-        self.curl_use_subprocess = False
-        if curl_path:
-            # Replace requests with curl.
-            import human_curl as requests
-            if curl_use_subprocess:
-                # Use subprocess to call curl.
-                self.curl_use_subprocess = True
 
 
     def __call__(self):
@@ -209,9 +203,9 @@ class QGConnector:
                 data = urlparse.parse_qs(data)
                 logger.debug('Converted:\n%s' % str(data))
         elif api_version in ('am', 'was'):
-            if type(data) == lxml.etree._Element:
+            if type(data) == etree._Element:
                 logger.debug('Converting lxml.builder.E to string')
-                data = lxml.etree.tostring(data)
+                data = etree.tostring(data)
                 logger.debug('Converted:\n%s' % data)
         return data
 
@@ -264,64 +258,30 @@ class QGConnector:
         logger.debug('url =\n%s' % (str(url)))
         logger.debug('data =\n%s' % (str(data)))
         logger.debug('headers =\n%s' % (str(headers)))
-        if self.curl_use_subprocess:
-            # Use Subprocess to call curl.
-            curl_call = ['curl', '-k', '-u', '%s:%s' % (self.auth[0], self.auth[1]), url]
-            # Insert headers.
-            for header in headers:
-                for i in ['-H', '%s: %s' % (header, headers[header])]:
-                    curl_call.insert(len(curl_call)-1, i)
-            # Check for POST data.
-            if data:
-                # Always being sent a dictionary.
-                if type(data) == dict:
-                    for i in data:
-                        # Convert one item list to a string.
-                        if type(data[i])==list:
-                            data[i]=data[i][0]
-                    # Parameterize data.
-                    data = urllib.urlencode(data)
-                # Insert data.
-                for i in ['-d', data]:
-                    curl_call.insert(len(curl_call)-1, i)
-            # Check for proxy.
-            if self.proxies:
-                # Insert proxy info before url.
-                for i in ['--proxy', self.proxies['https']]:
-                    curl_call.insert(len(curl_call)-1, i)
-            logger.debug('curl_call =\n%s' % (str(curl_call)))
-            print 'curl_call =\n%s' % (str(curl_call))
-            p = subprocess.Popen(curl_call, stdout=subprocess.PIPE)
-            out, err = p.communicate()
-            request = str(out)
-            logger.debug('response text =\n%s' % (str(request)))
-            return request
+        if http_method == 'get':
+            # GET
+            logger.debug('GET request.')
+            request = requests.get(url, params=data, auth=self.auth, headers=headers, proxies=self.proxies)
         else:
-            # Do not use Subprocess to call curl.
-            if http_method == 'get':
-                # GET
-                logger.debug('GET request.')
-                request = requests.get(url, params=data, auth=self.auth, headers=headers, proxies=self.proxies)
-            else:
-                # POST
-                logger.debug('POST request.')
-                # Make POST request.
-                request = requests.post(url, data=data, auth=self.auth, headers=headers, proxies=self.proxies)
-            logger.debug('response headers =\n%s' % (str(request.headers)))
-            #
-            # Remember how many times left user can make against api_call.
-            try:
-                self.rate_limit_remaining[api_call] = int(request.headers['x-ratelimit-remaining'])
-                logger.debug('rate limit for api_call, %s = %s' % (api_call, self.rate_limit_remaining[api_call]))
-            except KeyError, e:
-                # Likely a bad api_call.
-                logger.debug(e)
-                pass
-            except TypeError, e:
-                # Likely an asset search api_call.
-                logger.debug(e)
-                pass
-            logger.debug('response text =\n%s' % (str(request.content)))
-            # Check to see if there was an error.
-            request.raise_for_status()
-            return request.content
\ No newline at end of file
+            # POST
+            logger.debug('POST request.')
+            # Make POST request.
+            request = requests.post(url, data=data, auth=self.auth, headers=headers, proxies=self.proxies)
+        logger.debug('response headers =\n%s' % (str(request.headers)))
+        #
+        # Remember how many times left user can make against api_call.
+        try:
+            self.rate_limit_remaining[api_call] = int(request.headers['x-ratelimit-remaining'])
+            logger.debug('rate limit for api_call, %s = %s' % (api_call, self.rate_limit_remaining[api_call]))
+        except KeyError, e:
+            # Likely a bad api_call.
+            logger.debug(e)
+            pass
+        except TypeError, e:
+            # Likely an asset search api_call.
+            logger.debug(e)
+            pass
+        logger.debug('response text =\n%s' % (str(request.content)))
+        # Check to see if there was an error.
+        request.raise_for_status()
+        return request.content
\ No newline at end of file
